pub struct ArchetypeEdge {
pub add: Option<ArchetypeId>,
pub remove: Option<ArchetypeId>,
}Expand description
Cached archetype transition when a component is added or removed.
Fields
add: Option<ArchetypeId>Archetype reached by adding a component of this type.
remove: Option<ArchetypeId>Archetype reached by removing a component of this type.