pub struct TestClock { /* private fields */ }Expand description
Manually controllable time source for deterministic tests.
Advance time with set or advance_secs.
Implementations
Sourceimpl TestClock
impl TestClock
Sourcepub fn advance_secs(&mut self, secs: i64)
pub fn advance_secs(&mut self, secs: i64)
Advance the clock by the given number of seconds.
Sourcepub fn advance_micros(&mut self, us: i64)
pub fn advance_micros(&mut self, us: i64)
Advance the clock by the given number of microseconds.