EventWriter

Struct EventWriter 

pub struct EventWriter<'w, T: Send + 'static> { /* private fields */ }
Exclusive write access to the Events<T> resource.

Use this in a system to send events that other systems can read on the next schedule tick via EventReader<T>.

ⓘ
fn fire_cannon(mut writer: EventWriter<'_, CannonFired>) {
    writer.send(CannonFired { power: 9000 });
}

Implementations

Source

impl<'w, T: Send + 'static> EventWriter<'w, T>

pub fn send(&mut self, event: T)

Send an event. Readable by EventReader<T> systems on the next tick.