Module handler_function

Module handler_function 

Traits

Handler
Trait-object interface for all handler types.
IntoHandler
Converts a compatible function into a boxed Handler.

Functions

run_handler
Execute a handler against the world with the given request.
run_json_handler
Deserialize JSON, run a Handler, serialize the response as JSON.
run_json_handler_function
JSON boundary helper for any function that implements IntoHandler.
run_json_handler_value
Deserialize JSON, run a Handler, and return the response as serde_json::Value.