run_json_handler_value

Function run_json_handler_value 

pub fn run_json_handler_value<Req, Resp>(
    handler: &mut dyn Handler<Req, Resp>,
    json_body: &str,
    world: &mut World,
) -> Result<Value, String>
where Req: DeserializeOwned, Resp: Serialize,
Deserialize JSON, run a Handler, and return the response as serde_json::Value.

Same as run_json_handler, but avoids a serialize-then-parse round trip when the transport layer needs a JSON value (for example axum Json<Value>).