ProtocolQuery

Trait ProtocolQuery 

pub trait ProtocolQuery:
    Serialize
    + for<'de> Deserialize<'de>
    + Send
    + Sync
    + 'static { }
Marker trait for read-only requests.

Queries request a snapshot of game state without side effects.

Bounds

Same as Command: Serialize + Deserialize + Send + Sync + 'static.

Renamed from Query to ProtocolQuery in #57 to free up the Query name for the far more frequently used ECS system parameter.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors