#[derive(Component)]Expand description
Derive macro that implements the Component trait for a struct.
This enables the type to be stored in ECS sparse-set component storage,
keyed by TypeId.
#[derive(Component)]Derive macro that implements the Component trait for a struct.
This enables the type to be stored in ECS sparse-set component storage,
keyed by TypeId.