pub fn run_json_handler<Req, Resp>(
handler: &mut dyn Handler<Req, Resp>,
json_body: &str,
world: &mut World,
) -> Result<String, String>where
Req: DeserializeOwned,
Resp: Serialize,Expand description
Deserialize JSON, run a Handler, serialize the response as JSON.
Transport adapters (for example generated axum routes) use this at the
HTTP boundary while keeping handler execution on World via
run_handler.